`print.tpm` <-
function (x, digits = max(3, getOption("digits") - 3), ...) {
    if (!inherits(x, "tpm"))
        stop("Use only with 'tpm' objects.\n")
    cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), "\n\n", sep = "")
    if (is.matrix(coefs <- x$coef)) {
        coefs <- if (x$IRT.param) IRT.parm(x)$parms else object$coef
        coefs[, 1] <- plogis(coefs[, 1]) * x$max.guessing
        p <- length(coefs) - 1
        cat("Coefficients:\n")
        print(round(coefs, 3), print.gap = 2, quote = FALSE)
    } else
        cat("No coefficients\n")
    cat("\nLog.Lik:", round(x$log.Lik, 3))
    cat("\n\n")
    invisible(x)
}

